
#Chapter 11: Multiple regression
#Read in data

# Let's read in data using the Rstudio interface. First make sure that you downloaded the datafile 
# for this example from the  Supplementary Online Material [C11.multipleregression.csv] and 
# saved this somewhere on your hard drive.

# We will now upload this file into R. To do this, click on 'Session' in the taskbar, then go to 
# 'Set Working Directory' and then click on 'Choose Directory...' R will then open a
# familiar-looking file directory. Choose the folder on your in which you have the saved the datafile.

# Read in the csv file and give the data the name c11_data
c11_data <- read.csv('C11.multipleregression.csv')

# Another way to do this is to simply go to 'Files' in the bottom right hand 
# window of RStudio and find the downloaded file there. You can then click on
# the file and click 'import dataset...'. You can name the datafile in the window
# that pops up.

# Run a simple regression with one predictor (i.e., autonomous motivation)
model1 <- lm(jobsatisfaction ~ autonomousmotivation, data = c11_data)
summary(model1)

# Run a model with z-standardised independent and dependent variables, using the scale function
model1z <- lm(scale(jobsatisfaction) ~ scale(autonomousmotivation), data = c11_data)
summary(model1z)

# Run a multiple regression with two predictors (i.e., autonomous motivation and job status)
model2 <- lm(jobsatisfaction ~ autonomousmotivation + jobstatus, data = c11_data)
summary(model2)

# Run a model with z-standardised independent and dependent variables, using the scale function
model2z <- lm(scale(jobsatisfaction) ~ scale(autonomousmotivation) + scale(jobstatus), data = c11_data)
summary(model2z)

# Compare model1 with model2 using the ANOVA function
anova(model1, model2)

